@@ -1,40 +1,45 @@
 package Lingua::AR::Db;
 
+use 5.008006;
 use strict;
 use warnings;
 use utf8;
+
+use Lingua::AR::Word::Encode;		#needed to encode the name into ArabTeX encoding
 use Switch;
 
 
-our $VERSION = '1.5.2';
+our @ISA = qw();
+
+our $VERSION = '1.4';
 
 
 sub new{
 
-	my $class=$_[0];
-	my $this={
-		_folder=>$_[1],
-		_lang=>$_[2]
-	};
+	my $this={};
+	$this->{FOLDER}=$_[1];
+	$this->{LANG}=$_[2];
 
-	if(!-e $this->{_folder}){
-		warn "$this->{_folder} doesn't exists..creating it";
-		mkdir $this->{_folder}, 0755 or die "Can't create the $this->{folder} directory: $!\n";
+	if(!-e $this->{FOLDER}){
+		warn "$this->{FOLDER} doesn't exists..creating it";
+		mkdir $this->{FOLDER}, 0755 or die "Can't create the $this->{FOLDER} directory: $!\n";
 	}
 
-	bless($this,$class);
+	bless($this);
+
+return $this;
 }
 
 
 
 sub translate{
 
-	my ($db,$word)=@_;
+	my $word=$_[0];
+	my $db=$_[1];
+	my $translation="NotFound";
 
-	my $translation="TRANSLATION: NotFound\n\n";
-
-	my $input=Lingua::AR::Word::encode($word->{_stem});
-	$input=($db->{_folder})."/%".$input;
+	my $input=Lingua::AR::Word::encode(Lingua::AR::Word::stem($word));
+	$input=($db->{FOLDER})."/%".$input;
 
 	if (-e $input){
 		open DICT, "<".$input or die "Error in opening $input: $!";
@@ -43,13 +48,13 @@ sub translate{
 		my $found=0;
 		while($found==0 and my $line=<DICT>){
 			chomp($line);
-			if($line=~/^($word->{_word})/){
-				$translation="TRANSLATION: $'\n\n";
+			if($line=~/^$word/){
+				$translation=$';
 				$found=1;
 			}
 		}
 		if(!$found){
-			$translation="No translation found\n\n";
+			print "No translation found\n";
 		}
 	}
 	else{
@@ -78,7 +83,7 @@ sub display_html{ # exports the dictionary in html form
 	foreach my $letter (@alphabet){
 	print INDEX "<h2>$letter</h2>\n<ol>\n";
 	$letter=Lingua::AR::Word::encode($letter);
-	my @dicts=glob($this->{_folder}."/%$letter*");
+	my @dicts=glob($this->{FOLDER}."/%$letter*");
 	
 print "Letter: $letter\n";
 print "dictionaries: @dicts\n";
@@ -201,7 +206,7 @@ sub display_latex{ # creates the LaTeX source file for the whole dictionary
 }
 
 
-sub importation{
+sub import{
 
 	my $file;
 	my $transl;
@@ -275,7 +280,6 @@ print "Importation completed:
 
 }
 
-
 1;
 __END__
 
@@ -285,23 +289,22 @@ Lingua::AR::Db - Perl extension for translating Arabic words into another langua
 
 =head1 SYNOPSIS
 
-  use utf8;
-  use Lingua::AR::Word;
   use Lingua::AR::Db;
+  use Lingua::AR::Word;
 
+my $db=Lingua::AR::Db->new("./dicts","en");
 my $word=Lingua::AR::Word->new(ARABIC_WORD_IN_UTF8);
-my $db=Lingua::AR::Db->new(DICT_FOLDER,LANGUAGE);
 
 
 open FOUTPUT, ">>TEST" or die "Cannot create TEST: $!\n";
 binmode(FOUTPUT,":utf8");
-print FOUTPUT $db->translate($word);
+print FOUTPUT $word->get_translation($db);
 close FOUTPUT;
 
 
 $db->display_html();
 $db->display_latex();
-$db->importation(FILE);
+$db->import("file");
 
 =head1 DESCRIPTION
 
